@@ -81,7 +81,6 @@ static int getgrent_to_file(FILE *output) {
   size_t buflen = 1024;
   int errnop;
   enum nss_status ret;
-  char *member;
   int idx;
   
   _nss_cache_setgrent_path(GROUP_FILE);
@@ -201,7 +200,7 @@ static int getspent_to_file(FILE *output) {
 //
 // creates a copy of the passwd map as read by nss_cache.c
 
-static int gen_getpwent_data() {
+static int gen_getpwent_data(void) {
 
   char filename[NSS_CACHE_PATH_LENGTH];
   FILE *output;
@@ -227,7 +226,7 @@ static int gen_getpwent_data() {
 //
 // creates a copy of the group map as read by nss_cache.c
 
-static int gen_getgrent_data() {
+static int gen_getgrent_data(void) {
 
   char filename[NSS_CACHE_PATH_LENGTH];
   FILE *output;
@@ -253,7 +252,7 @@ static int gen_getgrent_data() {
 //
 // creates a copy of the shadow map as read by nss_cache.c
 
-static int gen_getspent_data() {
+static int gen_getspent_data(void) {
 
   char filename[NSS_CACHE_PATH_LENGTH];
   FILE *output;
